summaryrefslogtreecommitdiffstats
path: root/kpilot/conduits/abbrowserconduit
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/conduits/abbrowserconduit')
-rw-r--r--kpilot/conduits/abbrowserconduit/abbrowser-conduit.cc110
-rw-r--r--kpilot/conduits/abbrowserconduit/abbrowser-conduit.h16
-rw-r--r--kpilot/conduits/abbrowserconduit/abbrowser-setup.cc44
-rw-r--r--kpilot/conduits/abbrowserconduit/abbrowser-setup.h4
-rw-r--r--kpilot/conduits/abbrowserconduit/kabcRecord.cc54
-rw-r--r--kpilot/conduits/abbrowserconduit/kabcRecord.h36
-rw-r--r--kpilot/conduits/abbrowserconduit/resolutionDialog.cc62
-rw-r--r--kpilot/conduits/abbrowserconduit/resolutionDialog.h8
-rw-r--r--kpilot/conduits/abbrowserconduit/resolutionTable.h16
9 files changed, 175 insertions, 175 deletions
diff --git a/kpilot/conduits/abbrowserconduit/abbrowser-conduit.cc b/kpilot/conduits/abbrowserconduit/abbrowser-conduit.cc
index bf038bb2..11e25f2d 100644
--- a/kpilot/conduits/abbrowserconduit/abbrowser-conduit.cc
+++ b/kpilot/conduits/abbrowserconduit/abbrowser-conduit.cc
@@ -33,10 +33,10 @@
#include "options.h"
-#include <qtimer.h>
-#include <qtextcodec.h>
-#include <qfile.h>
-#include <qregexp.h>
+#include <tqtimer.h>
+#include <tqtextcodec.h>
+#include <tqfile.h>
+#include <tqregexp.h>
#include <kabc/stdaddressbook.h>
#include <kabc/resourcefile.h>
@@ -110,7 +110,7 @@ using namespace KABC;
*********************************************************************/
-AbbrowserConduit::AbbrowserConduit(KPilotLink * o, const char *n, const QStringList & a):
+AbbrowserConduit::AbbrowserConduit(KPilotLink * o, const char *n, const TQStringList & a):
ConduitAction(o, n, a),
aBook(0L),
fAddressAppInfo(0L),
@@ -153,7 +153,7 @@ AbbrowserConduit::~AbbrowserConduit()
/* Builds the map which links record ids to uid's of Addressee
*/
-void AbbrowserConduit::_mapContactsToPilot(QMap < recordid_t, QString > &idContactMap)
+void AbbrowserConduit::_mapContactsToPilot(TQMap < recordid_t, TQString > &idContactMap)
{
FUNCTIONSETUP;
@@ -163,7 +163,7 @@ void AbbrowserConduit::_mapContactsToPilot(QMap < recordid_t, QString > &idConta
contactIter != aBook->end(); ++contactIter)
{
Addressee aContact = *contactIter;
- QString recid = aContact.custom(KABCSync::appString, KABCSync::idString);
+ TQString recid = aContact.custom(KABCSync::appString, KABCSync::idString);
if(!recid.isEmpty())
{
recordid_t id = recid.toULong();
@@ -400,7 +400,7 @@ bool AbbrowserConduit::_saveAddressBook()
else {
KIO::NetAccess::removeTempFile(fABookFile);
}
- QFile backup(fABookFile + CSL1("~"));
+ TQFile backup(fABookFile + CSL1("~"));
backup.remove();
}
@@ -524,13 +524,13 @@ void AbbrowserConduit::showAddresses(
// Local block
{
- QString dbpath = fLocalDatabase->dbPathName();
+ TQString dbpath = fLocalDatabase->dbPathName();
DEBUGKPILOT << fname << ": Local database path " << dbpath << endl;
}
if ( syncMode().isTest() )
{
- QTimer::singleShot(0, this, SLOT(slotTestRecord()));
+ TQTimer::singleShot(0, this, TQT_SLOT(slotTestRecord()));
return true;
}
@@ -561,7 +561,7 @@ void AbbrowserConduit::showAddresses(
allIds=fDatabase->idList();
}
- QValueVector<int> v(4);
+ TQValueVector<int> v(4);
v[0] = AbbrowserSettings::custom0();
v[1] = AbbrowserSettings::custom1();
v[2] = AbbrowserSettings::custom2();
@@ -580,7 +580,7 @@ void AbbrowserConduit::showAddresses(
for this, and no longer purge the whole addressbook before the sync to
prevent data loss in case of connection loss. */
- QTimer::singleShot(0, this, SLOT(slotPalmRecToPC()));
+ TQTimer::singleShot(0, this, TQT_SLOT(slotPalmRecToPC()));
return true;
}
@@ -596,7 +596,7 @@ void AbbrowserConduit::slotPalmRecToPC()
{
DEBUGKPILOT << fname << ": Done; change to PCtoHH phase." << endl;
abiter = aBook->begin();
- QTimer::singleShot(0, this, SLOT(slotPCRecToPalm()));
+ TQTimer::singleShot(0, this, TQT_SLOT(slotPCRecToPalm()));
return;
}
@@ -614,7 +614,7 @@ void AbbrowserConduit::slotPalmRecToPC()
if(!palmRec)
{
abiter = aBook->begin();
- QTimer::singleShot(0, this, SLOT(slotPCRecToPalm()));
+ TQTimer::singleShot(0, this, TQT_SLOT(slotPCRecToPalm()));
return;
}
@@ -622,7 +622,7 @@ void AbbrowserConduit::slotPalmRecToPC()
if(syncedIds.contains(palmRec->id()))
{
KPILOT_DELETE(palmRec);
- QTimer::singleShot(0, this, SLOT(slotPalmRecToPC()));
+ TQTimer::singleShot(0, this, TQT_SLOT(slotPalmRecToPC()));
return;
}
@@ -650,7 +650,7 @@ void AbbrowserConduit::slotPalmRecToPC()
KPILOT_DELETE(palmRec);
KPILOT_DELETE(backupRec);
- QTimer::singleShot(0, this, SLOT(slotPalmRecToPC()));
+ TQTimer::singleShot(0, this, TQT_SLOT(slotPalmRecToPC()));
}
@@ -664,7 +664,7 @@ void AbbrowserConduit::slotPCRecToPalm()
{
DEBUGKPILOT << fname << ": Done; change to delete records." << endl;
pilotindex = 0;
- QTimer::singleShot(0, this, SLOT(slotDeletedRecord()));
+ TQTimer::singleShot(0, this, TQT_SLOT(slotDeletedRecord()));
return;
}
@@ -678,12 +678,12 @@ void AbbrowserConduit::slotPCRecToPalm()
{
DEBUGKPILOT << fname << ": address with id " << ad.uid() <<
" marked archived, so don't sync." << endl;
- QTimer::singleShot(0, this, SLOT(slotPCRecToPalm()));
+ TQTimer::singleShot(0, this, TQT_SLOT(slotPCRecToPalm()));
return;
}
- QString recID(ad.custom(KABCSync::appString, KABCSync::idString));
+ TQString recID(ad.custom(KABCSync::appString, KABCSync::idString));
bool ok;
recordid_t rid = recID.toLong(&ok);
if (recID.isEmpty() || !ok || !rid)
@@ -691,7 +691,7 @@ void AbbrowserConduit::slotPCRecToPalm()
DEBUGKPILOT << fname << ": This is a new record." << endl;
// it's a new item(no record ID and not inserted by the Palm -> PC sync), so add it
syncAddressee(ad, 0L, 0L);
- QTimer::singleShot(0, this, SLOT(slotPCRecToPalm()));
+ TQTimer::singleShot(0, this, TQT_SLOT(slotPCRecToPalm()));
return;
}
@@ -699,7 +699,7 @@ void AbbrowserConduit::slotPCRecToPalm()
if (syncedIds.contains(rid))
{
DEBUGKPILOT << ": address with id " << rid << " already synced." << endl;
- QTimer::singleShot(0, this, SLOT(slotPCRecToPalm()));
+ TQTimer::singleShot(0, this, TQT_SLOT(slotPCRecToPalm()));
return;
}
@@ -742,7 +742,7 @@ void AbbrowserConduit::slotPCRecToPalm()
syncedIds.append(rid);
// done with the sync process, go on with the next one:
- QTimer::singleShot(0, this, SLOT(slotPCRecToPalm()));
+ TQTimer::singleShot(0, this, TQT_SLOT(slotPCRecToPalm()));
}
@@ -755,13 +755,13 @@ void AbbrowserConduit::slotDeletedRecord()
if(!backupRec || isFirstSync() )
{
KPILOT_DELETE(backupRec);
- QTimer::singleShot(0, this, SLOT(slotDeleteUnsyncedPCRecords()));
+ TQTimer::singleShot(0, this, TQT_SLOT(slotDeleteUnsyncedPCRecords()));
return;
}
recordid_t id = backupRec->id();
- QString uid = addresseeMap[id];
+ TQString uid = addresseeMap[id];
Addressee e = aBook->findByUid(uid);
DEBUGKPILOT << fname << ": now looking at palm id: ["
@@ -796,7 +796,7 @@ void AbbrowserConduit::slotDeletedRecord()
KPILOT_DELETE(palmRec);
KPILOT_DELETE(backupAddr);
KPILOT_DELETE(backupRec);
- QTimer::singleShot(0, this, SLOT(slotDeletedRecord()));
+ TQTimer::singleShot(0, this, TQT_SLOT(slotDeletedRecord()));
}
@@ -806,9 +806,9 @@ void AbbrowserConduit::slotDeleteUnsyncedPCRecords()
FUNCTIONSETUP;
if ( syncMode()==SyncMode::eCopyHHToPC )
{
- QStringList uids;
+ TQStringList uids;
RecordIDList::iterator it;
- QString uid;
+ TQString uid;
for ( it = syncedIds.begin(); it != syncedIds.end(); ++it)
{
uid=addresseeMap[*it];
@@ -829,7 +829,7 @@ void AbbrowserConduit::slotDeleteUnsyncedPCRecords()
}
}
}
- QTimer::singleShot(0, this, SLOT(slotDeleteUnsyncedHHRecords()));
+ TQTimer::singleShot(0, this, TQT_SLOT(slotDeleteUnsyncedHHRecords()));
}
@@ -852,7 +852,7 @@ void AbbrowserConduit::slotDeleteUnsyncedHHRecords()
}
}
}
- QTimer::singleShot(0, this, SLOT(slotCleanup()));
+ TQTimer::singleShot(0, this, TQT_SLOT(slotCleanup()));
}
@@ -874,7 +874,7 @@ void AbbrowserConduit::slotCleanup()
}
// Write out the sync maps
- QString syncFile = fLocalDatabase->dbPathName() + CSL1(".sync");
+ TQString syncFile = fLocalDatabase->dbPathName() + CSL1(".sync");
DEBUGKPILOT << fname << ": Writing sync map to " << syncFile << endl;
KSaveFile map( syncFile );
if ( map.status() == 0 )
@@ -1215,7 +1215,7 @@ bool AbbrowserConduit::_savePalmAddr(PilotAddress *palmAddr, Addressee &pcAddr)
abId = pcAddr.custom(KABCSync::appString, KABCSync::idString).toUInt();
if(abId != pilotId)
{
- pcAddr.insertCustom(KABCSync::appString, KABCSync::idString, QString::number(pilotId));
+ pcAddr.insertCustom(KABCSync::appString, KABCSync::idString, TQString::number(pilotId));
return true;
}
@@ -1230,16 +1230,16 @@ bool AbbrowserConduit::_savePCAddr(Addressee &pcAddr, PilotAddress*,
FUNCTIONSETUP;
DEBUGKPILOT<<"Before _savePCAddr, pcAddr.custom="<<pcAddr.custom(KABCSync::appString, KABCSync::idString)<<endl;
- QString pilotId = pcAddr.custom(KABCSync::appString, KABCSync::idString);
+ TQString pilotId = pcAddr.custom(KABCSync::appString, KABCSync::idString);
long pilotIdL = pilotId.toLong();
if(!pilotId.isEmpty())
{
// because we maintain a mapping between pilotId -> kabc uid, whenever we add
// a new relationship, we have to remove any old mapping that would tie a different
// pilot id -> this kabc uid
- QMap < recordid_t, QString>::iterator it;
+ TQMap < recordid_t, TQString>::iterator it;
for ( it = addresseeMap.begin(); it != addresseeMap.end(); ++it ) {
- QString kabcUid = it.data();
+ TQString kabcUid = it.data();
if (kabcUid == pcAddr.uid()) {
addresseeMap.remove(it);
break;
@@ -1317,8 +1317,8 @@ bool AbbrowserConduit::_equal(const PilotAddress *piAddress, const Addressee &ab
{
// Check that the name of the category of the HH record
// is one matching the PC record.
- QString addressCategoryLabel = fAddressAppInfo->categoryName(piAddress->category());
- QString cat = KABCSync::bestMatchedCategoryName(abEntry.categories(),
+ TQString addressCategoryLabel = fAddressAppInfo->categoryName(piAddress->category());
+ TQString cat = KABCSync::bestMatchedCategoryName(abEntry.categories(),
*fAddressAppInfo, piAddress->category());
if(!_equal(cat, addressCategoryLabel))
{
@@ -1330,22 +1330,22 @@ bool AbbrowserConduit::_equal(const PilotAddress *piAddress, const Addressee &ab
if (flags & eqFlagsPhones)
{
// first, look for missing e-mail addresses on either side
- QStringList abEmails(abEntry.emails());
- QStringList piEmails(piAddress->getEmails());
+ TQStringList abEmails(abEntry.emails());
+ TQStringList piEmails(piAddress->getEmails());
if (abEmails.count() != piEmails.count())
{
DEBUGKPILOT << fname << ": email count not equal" << endl;
return false;
}
- for (QStringList::Iterator it = abEmails.begin(); it != abEmails.end(); it++) {
+ for (TQStringList::Iterator it = abEmails.begin(); it != abEmails.end(); it++) {
if (!piEmails.contains(*it))
{
DEBUGKPILOT << fname << ": pilot e-mail missing" << endl;
return false;
}
}
- for (QStringList::Iterator it = piEmails.begin(); it != piEmails.end(); it++) {
+ for (TQStringList::Iterator it = piEmails.begin(); it != piEmails.end(); it++) {
if (!abEmails.contains(*it))
{
DEBUGKPILOT << fname << ": kabc e-mail missing" << endl;
@@ -1483,8 +1483,8 @@ bool AbbrowserConduit::_equal(const PilotAddress *piAddress, const Addressee &ab
@pc, @backup, @palm ... entries of the according databases
@returns string of the merged entries.
*/
-QString AbbrowserConduit::_smartMergeString(const QString &pc, const QString & backup,
- const QString & palm, ConflictResolution confRes)
+TQString AbbrowserConduit::_smartMergeString(const TQString &pc, const TQString & backup,
+ const TQString & palm, ConflictResolution confRes)
{
FUNCTIONSETUP;
@@ -1493,7 +1493,7 @@ QString AbbrowserConduit::_smartMergeString(const QString &pc, const QString & b
// If this is a first sync, we don't have a backup record, so
if(isFirstSync() || backup.isEmpty()) {
- if (pc.isEmpty() && palm.isEmpty() ) return QString::null;
+ if (pc.isEmpty() && palm.isEmpty() ) return TQString::null;
if(pc.isEmpty()) return palm;
if(palm.isEmpty()) return pc;
} else {
@@ -1512,7 +1512,7 @@ QString AbbrowserConduit::_smartMergeString(const QString &pc, const QString & b
case SyncAction::ePreviousSyncOverrides: return backup; break;
default: break;
}
- return QString::null;
+ return TQString::null;
}
@@ -1535,9 +1535,9 @@ bool AbbrowserConduit::_buildResolutionTable(ResolutionTable*tab, const Addresse
#define appendGen(desc, abfield, palmfield) \
tab->append(new ResolutionItem(desc, tab->fExistItems, \
- (!pcAddr.isEmpty())?(abfield):(QString::null), \
- (palmAddr)?(palmAddr->palmfield):(QString::null), \
- (backupAddr)?(backupAddr->palmfield):(QString::null) ))
+ (!pcAddr.isEmpty())?(abfield):(TQString::null), \
+ (palmAddr)?(palmAddr->palmfield):(TQString::null), \
+ (backupAddr)?(backupAddr->palmfield):(TQString::null) ))
#define appendAddr(desc, abfield, palmfield) \
appendGen(desc, abfield, getField(palmfield))
#define appendGenPhone(desc, abfield, palmfield) \
@@ -1572,12 +1572,12 @@ bool AbbrowserConduit::_buildResolutionTable(ResolutionTable*tab, const Addresse
appendAddr(i18n("Postal code"), abAddress.postalCode(), entryZip);
appendAddr(i18n("Country"), abAddress.country(), entryCountry);
- QString palmAddrCategoryLabel;
+ TQString palmAddrCategoryLabel;
if (palmAddr)
{
palmAddrCategoryLabel = fAddressAppInfo->categoryName(palmAddr->category());
}
- QString backupAddrCategoryLabel;
+ TQString backupAddrCategoryLabel;
if (backupAddr)
{
backupAddrCategoryLabel = fAddressAppInfo->categoryName(backupAddr->category());
@@ -1588,7 +1588,7 @@ bool AbbrowserConduit::_buildResolutionTable(ResolutionTable*tab, const Addresse
tab->fExistItems,
!pcAddr.isEmpty() ?
KABCSync::bestMatchedCategoryName(pcAddr.categories(), *fAddressAppInfo, category) :
- QString::null,
+ TQString::null,
palmAddrCategoryLabel,
backupAddrCategoryLabel));
#undef appendGen
@@ -1601,7 +1601,7 @@ bool AbbrowserConduit::_buildResolutionTable(ResolutionTable*tab, const Addresse
/// This function just sets the phone number of type "type" to "phone"
-static inline void setPhoneNumber(Addressee &abEntry, int type, const QString &nr)
+static inline void setPhoneNumber(Addressee &abEntry, int type, const TQString &nr)
{
PhoneNumber phone = abEntry.phoneNumber(type);
phone.setNumber(nr);
@@ -1746,7 +1746,7 @@ bool AbbrowserConduit::_smartMergeAddressee(Addressee &pcAddr,
if (!mergeOk)
{
- QString dlgText;
+ TQString dlgText;
if (!palmAddr)
{
dlgText=i18n("The following address entry was changed, but does no longer exist on the handheld. Please resolve this conflict:");
@@ -1839,7 +1839,7 @@ Addressee AbbrowserConduit::_findMatch(const PilotAddress & pilotAddress) const
// first, use the pilotID to UID map to find the appropriate record
if( !isFirstSync() && (pilotAddress.id() > 0) )
{
- QString id(addresseeMap[pilotAddress.id()]);
+ TQString id(addresseeMap[pilotAddress.id()]);
DEBUGKPILOT << fname << ": PilotRecord has id " << pilotAddress.id() << ", mapped to " << id << endl;
if(!id.isEmpty())
{
@@ -1852,7 +1852,7 @@ Addressee AbbrowserConduit::_findMatch(const PilotAddress & pilotAddress) const
for(AddressBook::Iterator iter = aBook->begin(); iter != aBook->end(); ++iter)
{
Addressee abEntry = *iter;
- QString recID(abEntry.custom(KABCSync::appString, KABCSync::idString));
+ TQString recID(abEntry.custom(KABCSync::appString, KABCSync::idString));
bool ok;
if (!recID.isEmpty() )
{
@@ -1893,5 +1893,5 @@ void AbbrowserConduit::slotTestRecord()
// Schedule more work.
++pilotindex;
- QTimer::singleShot(0, this, SLOT(slotTestRecord()));
+ TQTimer::singleShot(0, this, TQT_SLOT(slotTestRecord()));
}
diff --git a/kpilot/conduits/abbrowserconduit/abbrowser-conduit.h b/kpilot/conduits/abbrowserconduit/abbrowser-conduit.h
index 484f6129..22e94469 100644
--- a/kpilot/conduits/abbrowserconduit/abbrowser-conduit.h
+++ b/kpilot/conduits/abbrowserconduit/abbrowser-conduit.h
@@ -49,14 +49,14 @@ class Ticket;
using namespace KABC;
-typedef QValueList<recordid_t> RecordIDList;
+typedef TQValueList<recordid_t> RecordIDList;
class AbbrowserConduit : public ConduitAction
{
Q_OBJECT
public:
AbbrowserConduit(KPilotLink *o,const char *n = 0L,
- const QStringList &a = QStringList() );
+ const TQStringList &a = TQStringList() );
virtual ~AbbrowserConduit();
/*********************************************************************
@@ -97,7 +97,7 @@ private:
/* Given a list of contacts, creates the pilot id to contact key map
* and a list of new contacts in O(n) time (single pass) */
- void _mapContactsToPilot( QMap < recordid_t, QString> &idContactMap);
+ void _mapContactsToPilot( TQMap < recordid_t, TQString> &idContactMap);
/* Do the preperations before doSync or doBackup.
* Load contacts, set the pilot */
bool _prepare();
@@ -141,7 +141,7 @@ private:
/*********************************************************************
C O P Y R E C O R D S
*********************************************************************/
- inline bool _equal(const QString & str1, const QString & str2) const
+ inline bool _equal(const TQString & str1, const TQString & str2) const
{
return (str1.isEmpty() && str2.isEmpty()) || (str1 == str2);
} ;
@@ -168,8 +168,8 @@ private:
* @pc, @backup, @palm ... entries of the according databases
* @returns string of the merged entries.
*/
- QString _smartMergeString(const QString &pc, const QString & backup,
- const QString & palm, ConflictResolution confRes);
+ TQString _smartMergeString(const TQString &pc, const TQString & backup,
+ const TQString & palm, ConflictResolution confRes);
bool _buildResolutionTable(ResolutionTable*tab, const Addressee &pcAddr,
PilotAddress *backupAddr, PilotAddress *palmAddr);
bool _applyResolutionTable(ResolutionTable*tab, Addressee &pcAddr,
@@ -200,9 +200,9 @@ private:
int pilotindex;
bool abChanged;
/** addresseeMap maps record ids to IDs of Addressees. This is used to speed up searching the local addressbook */
- QMap < recordid_t, QString> addresseeMap;
+ TQMap < recordid_t, TQString> addresseeMap;
RecordIDList syncedIds, allIds;
- QString fABookFile;
+ TQString fABookFile;
AddressBook::Iterator abiter;
/** For a local file resource, we need to obtain a saveTicket
* when opening the abook, just in case we want to modify it
diff --git a/kpilot/conduits/abbrowserconduit/abbrowser-setup.h b/kpilot/conduits/abbrowserconduit/abbrowser-setup.h
index 71981dc0..47eff1cf 100644
--- a/kpilot/conduits/abbrowserconduit/abbrowser-setup.h
+++ b/kpilot/conduits/abbrowserconduit/abbrowser-setup.h
@@ -38,11 +38,11 @@ class KAboutData;
class AbbrowserWidgetSetup : public ConduitConfigBase
{
public:
- AbbrowserWidgetSetup(QWidget *,const char *);
+ AbbrowserWidgetSetup(TQWidget *,const char *);
virtual ~AbbrowserWidgetSetup();
virtual void load();
virtual void commit();
- static ConduitConfigBase *create(QWidget *,const char *);
+ static ConduitConfigBase *create(TQWidget *,const char *);
private:
AbbrowserWidget *fConfigWidget;
KAboutData *fAbout;
diff --git a/kpilot/conduits/abbrowserconduit/kabcRecord.cc b/kpilot/conduits/abbrowserconduit/kabcRecord.cc
index b5d68121..9b49a2ca 100644
--- a/kpilot/conduits/abbrowserconduit/kabcRecord.cc
+++ b/kpilot/conduits/abbrowserconduit/kabcRecord.cc
@@ -33,7 +33,7 @@
#include "options.h"
-#include <qregexp.h>
+#include <tqregexp.h>
#include <kglobal.h>
#include <kabc/addressee.h>
@@ -79,7 +79,7 @@ KABC::PhoneNumber::List KABCSync::getPhoneNumbers(const PilotAddress &a)
FUNCTIONSETUP;
KABC::PhoneNumber::List list;
- QString test;
+ TQString test;
PhoneSlot shownPhone = a.getShownPhone();
@@ -136,7 +136,7 @@ void KABCSync::setPhoneNumbers(const PilotAddressInfo &info,
const KABC::PhoneNumber::List &list)
{
FUNCTIONSETUP;
- QString test;
+ TQString test;
// clear all phone numbers (not e-mails) first
for ( PhoneSlot i = PhoneSlot::begin(); i.isValid() ; ++i )
@@ -144,7 +144,7 @@ void KABCSync::setPhoneNumbers(const PilotAddressInfo &info,
PilotAddressInfo::EPhoneType ind = a.getPhoneType( i );
if (ind != PilotAddressInfo::eEmail)
{
- a.setField(i, QString());
+ a.setField(i, TQString());
}
}
@@ -199,7 +199,7 @@ void KABCSync::setPhoneNumbers(const PilotAddressInfo &info,
// after setting the numbers, make sure that something sensible is set as the
// shownPhone on the Pilot if nothing is yet...
- QString pref = a.getField(a.getShownPhone());
+ TQString pref = a.getField(a.getShownPhone());
if (!a.getShownPhone().isValid() || pref.isEmpty())
{
DEBUGKPILOT << fname << ": Pilot's showPhone: ["
@@ -222,7 +222,7 @@ void KABCSync::setPhoneNumbers(const PilotAddressInfo &info,
}
}
-unsigned int KABCSync::bestMatchedCategory(const QStringList &pccategories,
+unsigned int KABCSync::bestMatchedCategory(const TQStringList &pccategories,
const PilotAddressInfo &info,
unsigned int hhcategory)
{
@@ -243,7 +243,7 @@ unsigned int KABCSync::bestMatchedCategory(const QStringList &pccategories,
// Look for the first category from the list which is available on
// the handheld as well.
- for(QStringList::ConstIterator it = pccategories.begin(); it != pccategories.end(); ++it)
+ for(TQStringList::ConstIterator it = pccategories.begin(); it != pccategories.end(); ++it)
{
// Do not map unknown to unfiled when looking for category
int c = info.findCategory( *it, false );
@@ -258,7 +258,7 @@ unsigned int KABCSync::bestMatchedCategory(const QStringList &pccategories,
return Pilot::Unfiled;
}
-void KABCSync::setCategory(KABC::Addressee & abEntry, const QString &cat)
+void KABCSync::setCategory(KABC::Addressee & abEntry, const TQString &cat)
{
if ( (!cat.isEmpty()))
{
@@ -267,24 +267,24 @@ void KABCSync::setCategory(KABC::Addressee & abEntry, const QString &cat)
}
-QString KABCSync::getFieldForHHCustom(
+TQString KABCSync::getFieldForHHCustom(
const unsigned int index,
const KABC::Addressee &abEntry,
const KABCSync::Settings &settings)
{
FUNCTIONSETUPL(4);
- QString retval;
+ TQString retval;
if (index>3)
{
WARNINGKPILOT << "Bad index number " << index << endl;
- retval = QString();
+ retval = TQString();
}
if (settings.customMapping().count() != 4)
{
WARNINGKPILOT << "Mapping does not have 4 elements." << index << endl;
- retval = QString();
+ retval = TQString();
}
switch (settings.custom(index))
@@ -296,9 +296,9 @@ QString KABCSync::getFieldForHHCustom(
}
else
{
- QString tmpfmt(KGlobal::locale()->dateFormat());
+ TQString tmpfmt(KGlobal::locale()->dateFormat());
KGlobal::locale()->setDateFormat(settings.dateFormat());
- QString ret(KGlobal::locale()->formatDate(abEntry.birthday().date()));
+ TQString ret(KGlobal::locale()->formatDate(abEntry.birthday().date()));
KGlobal::locale()->setDateFormat(tmpfmt);
retval = ret;
}
@@ -311,7 +311,7 @@ QString KABCSync::getFieldForHHCustom(
break;
case eCustomField:
default:
- retval = abEntry.custom(appString, CSL1("CUSTOM")+QString::number(index));
+ retval = abEntry.custom(appString, CSL1("CUSTOM")+TQString::number(index));
break;
}
@@ -321,7 +321,7 @@ QString KABCSync::getFieldForHHCustom(
void KABCSync::setFieldFromHHCustom(
const unsigned int index,
KABC::Addressee &abEntry,
- const QString &value,
+ const TQString &value,
const KABCSync::Settings &settings)
{
FUNCTIONSETUPL(4);
@@ -341,7 +341,7 @@ void KABCSync::setFieldFromHHCustom(
{
case eCustomBirthdate:
{
- QDate bdate;
+ TQDate bdate;
bool ok=false;
if (settings.dateFormat().isEmpty())
{
@@ -356,8 +356,8 @@ void KABCSync::setFieldFromHHCustom(
if (!ok)
{
- QString format = KGlobal::locale()->dateFormatShort();
- QRegExp re(CSL1("%[yY][^%]*"));
+ TQString format = KGlobal::locale()->dateFormatShort();
+ TQRegExp re(CSL1("%[yY][^%]*"));
format.remove(re); // Remove references to year and following punctuation
bdate = KGlobal::locale()->readDate(value, format, &ok);
}
@@ -382,7 +382,7 @@ void KABCSync::setFieldFromHHCustom(
break;
case eCustomField:
default:
- abEntry.insertCustom(appString, CSL1("CUSTOM")+QString::number(index), value);
+ abEntry.insertCustom(appString, CSL1("CUSTOM")+TQString::number(index), value);
break;
}
}
@@ -416,7 +416,7 @@ KABC::Address KABCSync::getAddress(const KABC::Addressee &abEntry, const KABCSyn
}
-QString KABCSync::getFieldForHHOtherPhone(const KABC::Addressee & abEntry, const KABCSync::Settings &s)
+TQString KABCSync::getFieldForHHOtherPhone(const KABC::Addressee & abEntry, const KABCSync::Settings &s)
{
switch(s.fieldForOtherPhone())
{
@@ -437,11 +437,11 @@ QString KABCSync::getFieldForHHOtherPhone(const KABC::Addressee & abEntry, const
case eTTYTTDPhone:
return abEntry.phoneNumber(KABC::PhoneNumber::Pcs).number();
default:
- return QString::null;
+ return TQString::null;
}
}
-void KABCSync::setFieldFromHHOtherPhone(KABC::Addressee & abEntry, const QString &nr, const KABCSync::Settings &s)
+void KABCSync::setFieldFromHHOtherPhone(KABC::Addressee & abEntry, const TQString &nr, const KABCSync::Settings &s)
{
int phoneType = 0;
switch (s.fieldForOtherPhone())
@@ -496,13 +496,13 @@ void KABCSync::setAddress(PilotAddress &toPilotAddr,
bool KABCSync::isArchived(const KABC::Addressee &addr)
{
- return addr.custom(KABCSync::appString, KABCSync::flagString) == QString::number(SYNCDEL);
+ return addr.custom(KABCSync::appString, KABCSync::flagString) == TQString::number(SYNCDEL);
}
void KABCSync::makeArchived(KABC::Addressee &addr)
{
FUNCTIONSETUP;
- addr.insertCustom(KABCSync::appString, KABCSync::flagString, QString::number(SYNCDEL));
+ addr.insertCustom(KABCSync::appString, KABCSync::flagString, TQString::number(SYNCDEL));
addr.removeCustom(KABCSync::appString, KABCSync::idString);
}
@@ -536,7 +536,7 @@ void KABCSync::copy(PilotAddress &toPilotAddr,
// Other field is an oddball and if the user has more than one field set
// as "Other" then only one will be carried over.
- QString oth = KABCSync::getFieldForHHOtherPhone(fromAbEntry,syncSettings);
+ TQString oth = KABCSync::getFieldForHHOtherPhone(fromAbEntry,syncSettings);
DEBUGKPILOT << fname << ": putting: ["<<oth<<"] into Palm's other"<<endl;
toPilotAddr.setPhoneField(PilotAddressInfo::eOther,
oth, PilotAddress::Replace);
@@ -650,7 +650,7 @@ void KABCSync::copy(KABC::Addressee &toAbEntry,
// pilot id may be zero(since it could be new) but couldn't hurt
// to even assign it to zero; let's us know what state the
// toAbEntry is in
- toAbEntry.insertCustom(KABCSync::appString, KABCSync::idString, QString::number(fromPiAddr.id()));
+ toAbEntry.insertCustom(KABCSync::appString, KABCSync::idString, TQString::number(fromPiAddr.id()));
KABCSync::setCategory(toAbEntry, appInfo.categoryName(fromPiAddr.category()));
diff --git a/kpilot/conduits/abbrowserconduit/resolutionDialog.cc b/kpilot/conduits/abbrowserconduit/resolutionDialog.cc
index 2749074f..aa8e2f14 100644
--- a/kpilot/conduits/abbrowserconduit/resolutionDialog.cc
+++ b/kpilot/conduits/abbrowserconduit/resolutionDialog.cc
@@ -28,11 +28,11 @@
#include "options.h"
-#include <qtimer.h>
-#include <qlabel.h>
-#include <qpushbutton.h>
-#include <qlistview.h>
-#include <qregexp.h>
+#include <tqtimer.h>
+#include <tqlabel.h>
+#include <tqpushbutton.h>
+#include <tqlistview.h>
+#include <tqregexp.h>
#include "resolutionTable.h"
#include "resolutionDialog_base.h"
@@ -46,16 +46,16 @@
* activated (stateChange), it sets the text of its parent (which is the
* controller, which is an instance of ResolutionCheckListItem, too).
**/
-class ResolutionCheckListItem : QCheckListItem {
+class ResolutionCheckListItem : TQCheckListItem {
public:
ResolutionCheckListItem(ResolutionItem*it, ResolutionTable*tb,
- QListView*parent);
- ResolutionCheckListItem(QString header, QString text,
+ TQListView*parent);
+ ResolutionCheckListItem(TQString header, TQString text,
ResolutionCheckListItem*parent);
~ResolutionCheckListItem() {};
virtual void stateChange(bool newstate);
- virtual void setValue(QString text);
- virtual void setCaption(QString caption);
+ virtual void setValue(TQString text);
+ virtual void setCaption(TQString caption);
protected:
void updateText();
@@ -65,20 +65,20 @@ protected:
/* The description of the entry, e.g. Backup, PC, Palm for the radio buttons,
* of the field name for the controllers
*/
- QString fCaption;
+ TQString fCaption;
/* The currrent value of the entry (for controllers this changes with the
* selected button */
- QString fText;
+ TQString fText;
};
ResolutionCheckListItem::ResolutionCheckListItem(ResolutionItem*it,
- ResolutionTable*tb, QListView*parent) :
- QCheckListItem(parent, QString::null, QCheckListItem::Controller),
+ ResolutionTable*tb, TQListView*parent) :
+ TQCheckListItem(parent, TQString::null, TQCheckListItem::Controller),
fResItem(it),
isController(true),
- fCaption(it?(it->fName):(QString::null)),
- fText(it?(it->fResolved):(QString::null))
+ fCaption(it?(it->fName):(TQString::null)),
+ fText(it?(it->fResolved):(TQString::null))
{
FUNCTIONSETUP;
if (it && tb)
@@ -86,7 +86,7 @@ ResolutionCheckListItem::ResolutionCheckListItem(ResolutionItem*it,
// If all three texts are identical, there is no need for
// resolution so don't show the radio items below
bool itemsEqual=true;
- QString testtext(QString::null);
+ TQString testtext(TQString::null);
const enum eExistItems its[3]={eExistsPC, eExistsPalm, eExistsBackup};
// get a valid text from a valid field, which will serve as the
// test text for the comparison
@@ -118,9 +118,9 @@ ResolutionCheckListItem::ResolutionCheckListItem(ResolutionItem*it,
setOpen(true);
}
-ResolutionCheckListItem::ResolutionCheckListItem(QString text, QString header,
+ResolutionCheckListItem::ResolutionCheckListItem(TQString text, TQString header,
ResolutionCheckListItem*parent) :
- QCheckListItem(parent, QString(), QCheckListItem::RadioButton),
+ TQCheckListItem(parent, TQString(), TQCheckListItem::RadioButton),
fResItem(0L),
isController(false),
fCaption(header),
@@ -140,7 +140,7 @@ void ResolutionCheckListItem::stateChange(bool newstate)
}
}
-void ResolutionCheckListItem::setValue(QString text)
+void ResolutionCheckListItem::setValue(TQString text)
{
FUNCTIONSETUP;
fText=text;
@@ -151,7 +151,7 @@ void ResolutionCheckListItem::setValue(QString text)
updateText();
}
-void ResolutionCheckListItem::setCaption(QString caption)
+void ResolutionCheckListItem::setCaption(TQString caption)
{
fCaption=caption;
updateText();
@@ -159,8 +159,8 @@ void ResolutionCheckListItem::setCaption(QString caption)
void ResolutionCheckListItem::updateText()
{
- QString newText(i18n("Entries in the resolution dialog. First the name of the field, then the entry from the Handheld or PC after the colon", "%1: %2").arg(fCaption).arg(fText));
- newText.replace(QRegExp(CSL1("\n")),
+ TQString newText(i18n("Entries in the resolution dialog. First the name of the field, then the entry from the Handheld or PC after the colon", "%1: %2").arg(fCaption).arg(fText));
+ newText.replace(TQRegExp(CSL1("\n")),
i18n("Denoting newlines in Address entries. No need to translate", " | "));
setText(0, newText);
}
@@ -171,8 +171,8 @@ void ResolutionCheckListItem::updateText()
*
*****************************************************************/
-ResolutionDlg::ResolutionDlg( QWidget* parent, KPilotLink*fH,
- const QString &caption, const QString &helpText, ResolutionTable*tab) :
+ResolutionDlg::ResolutionDlg( TQWidget* parent, KPilotLink*fH,
+ const TQString &caption, const TQString &helpText, ResolutionTable*tab) :
KDialogBase( parent, "ResolutionDlg", false, caption, Apply|Cancel, Apply),
tickleTimer(0L),
fHandle(fH),
@@ -189,20 +189,20 @@ ResolutionDlg::ResolutionDlg( QWidget* parent, KPilotLink*fH,
adjustSize();
resize(size());
- if (fHandle) tickleTimer=new QTimer(this, "TickleTimer");
+ if (fHandle) tickleTimer=new TQTimer(this, "TickleTimer");
if (tickleTimer)
{
- connect( tickleTimer, SIGNAL(timeout()), this, SLOT(_tickle()));
+ connect( tickleTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(_tickle()));
// tickle the palm every 10 seconds to prevent a timeout until the
// sync is really finished.
tickleTimer->start( 10000 );
}
- connect(fWidget->fKeepBoth, SIGNAL(clicked()), SLOT(slotKeepBoth()));
- connect(fWidget->fBackupValues, SIGNAL(clicked()), SLOT(slotUseBackup()));
- connect(fWidget->fPalmValues, SIGNAL(clicked()), SLOT(slotUsePalm()));
- connect(fWidget->fPCValues, SIGNAL(clicked()), SLOT(slotUsePC()));
+ connect(fWidget->fKeepBoth, TQT_SIGNAL(clicked()), TQT_SLOT(slotKeepBoth()));
+ connect(fWidget->fBackupValues, TQT_SIGNAL(clicked()), TQT_SLOT(slotUseBackup()));
+ connect(fWidget->fPalmValues, TQT_SIGNAL(clicked()), TQT_SLOT(slotUsePalm()));
+ connect(fWidget->fPCValues, TQT_SIGNAL(clicked()), TQT_SLOT(slotUsePC()));
}
void ResolutionDlg::adjustButtons(ResolutionTable*tab)
diff --git a/kpilot/conduits/abbrowserconduit/resolutionDialog.h b/kpilot/conduits/abbrowserconduit/resolutionDialog.h
index 5f41ba0f..d0b8fd52 100644
--- a/kpilot/conduits/abbrowserconduit/resolutionDialog.h
+++ b/kpilot/conduits/abbrowserconduit/resolutionDialog.h
@@ -42,10 +42,10 @@ class ResolutionDlg : public KDialogBase
Q_OBJECT
public:
- ResolutionDlg( QWidget* parent=0,
+ ResolutionDlg( TQWidget* parent=0,
KPilotLink*fH=0L,
- const QString &caption=QString(),
- const QString &helpText=QString(),
+ const TQString &caption=TQString(),
+ const TQString &helpText=TQString(),
ResolutionTable *tab=0L );
~ResolutionDlg();
@@ -60,7 +60,7 @@ protected:
void fillListView();
void adjustButtons(ResolutionTable*tab);
- QTimer* tickleTimer;
+ TQTimer* tickleTimer;
KPilotLink* fHandle;
ResolutionTable*fTable;
diff --git a/kpilot/conduits/abbrowserconduit/resolutionTable.h b/kpilot/conduits/abbrowserconduit/resolutionTable.h
index 760f962e..51c25190 100644
--- a/kpilot/conduits/abbrowserconduit/resolutionTable.h
+++ b/kpilot/conduits/abbrowserconduit/resolutionTable.h
@@ -29,7 +29,7 @@
*/
-#include <qvaluelist.h>
+#include <tqvaluelist.h>
#include "syncAction.h"
typedef enum eExistItems {
@@ -41,12 +41,12 @@ class ResolutionItem
{
public:
enum eExistItems fExistItems;
- QString fEntries[3];
- QString fResolved;
- QString fName;
+ TQString fEntries[3];
+ TQString fResolved;
+ TQString fName;
public:
ResolutionItem() {}
- ResolutionItem(QString name, int ex, QString pc, QString palm, QString backup):fExistItems((eExistItems)ex),fName(name)
+ ResolutionItem(TQString name, int ex, TQString pc, TQString palm, TQString backup):fExistItems((eExistItems)ex),fName(name)
{fEntries[0]=pc;fEntries[1]=palm; fEntries[2]=backup; /*fExistItems=(eExistItems)ex;*/ }
~ResolutionItem() {}
};
@@ -54,15 +54,15 @@ public:
/**
@author Reinhold Kainhofer
*/
-class ResolutionTable : public QPtrList<ResolutionItem>
+class ResolutionTable : public TQPtrList<ResolutionItem>
{
public:
- ResolutionTable():QPtrList<ResolutionItem>() {fResolution=SyncAction::eAskUser;};
+ ResolutionTable():TQPtrList<ResolutionItem>() {fResolution=SyncAction::eAskUser;};
~ResolutionTable() {};
SyncAction::ConflictResolution fResolution;
- QString labels[3];
+ TQString labels[3];
enum eExistItems fExistItems;
};
diff --git a/kpilot/conduits/abbrowserconduit/abbrowser-setup.cc b/kpilot/conduits/abbrowserconduit/abbrowser-setup.cc
index 4a2aa421..f4d80d2c 100644
--- a/kpilot/conduits/abbrowserconduit/abbrowser-setup.cc
+++ b/kpilot/conduits/abbrowserconduit/abbrowser-setup.cc
@@ -29,9 +29,9 @@
#include "options.h"
-#include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qbuttongroup.h>
+#include <tqcheckbox.h>
+#include <tqcombobox.h>
+#include <tqbuttongroup.h>
#include <kurlrequester.h>
#include <kaboutdata.h>
@@ -62,7 +62,7 @@ static KAboutData *createAbout()
return fAbout;
}
-AbbrowserWidgetSetup::AbbrowserWidgetSetup(QWidget *w, const char *n) :
+AbbrowserWidgetSetup::AbbrowserWidgetSetup(TQWidget *w, const char *n) :
ConduitConfigBase(w,n),
fConfigWidget(new AbbrowserWidget(w))
{
@@ -73,20 +73,20 @@ AbbrowserWidgetSetup::AbbrowserWidgetSetup(QWidget *w, const char *n) :
ConduitConfigBase::addAboutPage(fConfigWidget->tabWidget,fAbout);
fWidget=fConfigWidget;
fConfigWidget->fAbookFile->setMode(KFile::File);
-#define CM(a,b) connect(fConfigWidget->a,b,this,SLOT(modified()));
- CM(fSyncDestination,SIGNAL(clicked(int)));
- CM(fAbookFile,SIGNAL(textChanged(const QString &)));
- CM(fArchive,SIGNAL(toggled(bool)));
- CM(fConflictResolution,SIGNAL(activated(int)));
- CM(fOtherPhone,SIGNAL(activated(int)));
- CM(fAddress,SIGNAL(activated(int)));
- CM(fFax,SIGNAL(activated(int)));
- CM(fCustom0,SIGNAL(activated(int)));
- CM(fCustom1,SIGNAL(activated(int)));
- CM(fCustom2,SIGNAL(activated(int)));
- CM(fCustom3,SIGNAL(activated(int)));
- CM(fCustomDate, SIGNAL(activated(int)));
- CM(fCustomDate, SIGNAL(textChanged(const QString&)));
+#define CM(a,b) connect(fConfigWidget->a,b,this,TQT_SLOT(modified()));
+ CM(fSyncDestination,TQT_SIGNAL(clicked(int)));
+ CM(fAbookFile,TQT_SIGNAL(textChanged(const TQString &)));
+ CM(fArchive,TQT_SIGNAL(toggled(bool)));
+ CM(fConflictResolution,TQT_SIGNAL(activated(int)));
+ CM(fOtherPhone,TQT_SIGNAL(activated(int)));
+ CM(fAddress,TQT_SIGNAL(activated(int)));
+ CM(fFax,TQT_SIGNAL(activated(int)));
+ CM(fCustom0,TQT_SIGNAL(activated(int)));
+ CM(fCustom1,TQT_SIGNAL(activated(int)));
+ CM(fCustom2,TQT_SIGNAL(activated(int)));
+ CM(fCustom3,TQT_SIGNAL(activated(int)));
+ CM(fCustomDate, TQT_SIGNAL(activated(int)));
+ CM(fCustomDate, TQT_SIGNAL(textChanged(const TQString&)));
#undef CM
}
@@ -99,7 +99,7 @@ AbbrowserWidgetSetup::~AbbrowserWidgetSetup()
{
FUNCTIONSETUP;
- QButtonGroup*grp=fConfigWidget->fSyncDestination;
+ TQButtonGroup*grp=fConfigWidget->fSyncDestination;
AbbrowserSettings::setAddressbookType(grp->id(grp->selected()));
AbbrowserSettings::setFileName(fConfigWidget->fAbookFile->url());
AbbrowserSettings::setArchiveDeleted(fConfigWidget->fArchive->isChecked());
@@ -132,7 +132,7 @@ AbbrowserWidgetSetup::~AbbrowserWidgetSetup()
#endif
int fmtindex=fConfigWidget->fCustomDate->currentItem();
AbbrowserSettings::setCustomDateFormat(
- (fmtindex==0)?(QString::null):fConfigWidget->fCustomDate->currentText() );
+ (fmtindex==0)?(TQString::null):fConfigWidget->fCustomDate->currentText() );
AbbrowserSettings::self()->writeConfig();
unmodified();
@@ -175,7 +175,7 @@ AbbrowserWidgetSetup::~AbbrowserWidgetSetup()
fConfigWidget->fCustom1->setCurrentItem(AbbrowserSettings::custom1());
fConfigWidget->fCustom2->setCurrentItem(AbbrowserSettings::custom2());
fConfigWidget->fCustom3->setCurrentItem(AbbrowserSettings::custom3());
- QString datefmt=AbbrowserSettings::customDateFormat();
+ TQString datefmt=AbbrowserSettings::customDateFormat();
if (datefmt.isEmpty())
{
fConfigWidget->fCustomDate->setCurrentItem(0);
@@ -188,7 +188,7 @@ AbbrowserWidgetSetup::~AbbrowserWidgetSetup()
unmodified();
}
/* static */ ConduitConfigBase *AbbrowserWidgetSetup::create(QWidget *w, const char *n)
{
return new AbbrowserWidgetSetup(w,n);
}
@@ -188,7 +188,7 @@ AbbrowserWidgetSetup::~AbbrowserWidgetSetup()
unmodified();
}
-/* static */ ConduitConfigBase *AbbrowserWidgetSetup::create(QWidget *w, const char *n)
+/* static */ ConduitConfigBase *AbbrowserWidgetSetup::create(TQWidget *w, const char *n)
{
return new AbbrowserWidgetSetup(w,n);
diff --git a/kpilot/conduits/abbrowserconduit/kabcRecord.h b/kpilot/conduits/abbrowserconduit/kabcRecord.h
index 13a3e269..f27f0b1a 100644
--- a/kpilot/conduits/abbrowserconduit/kabcRecord.h
+++ b/kpilot/conduits/abbrowserconduit/kabcRecord.h
@@ -33,7 +33,7 @@
** Bug reports and questions can be sent to kde-pim@kde.org.
*/
-#include <qvaluevector.h>
+#include <tqvaluevector.h>
#include <kabc/phonenumber.h>
@@ -71,20 +71,20 @@ namespace KABCSync
{
public:
Settings();
- QString dateFormat() const
+ TQString dateFormat() const
{
return fDateFormat;
}
- void setDateFormat(const QString& s)
+ void setDateFormat(const TQString& s)
{
fDateFormat = s;
}
- const QValueVector<int> &customMapping() const
+ const TQValueVector<int> &customMapping() const
{
return fCustomMapping;
}
- void setCustomMapping(const QValueVector<int> &v)
+ void setCustomMapping(const TQValueVector<int> &v)
{
if (v.count()==4)
{
@@ -130,8 +130,8 @@ namespace KABCSync
fFaxTypeOnPC = v;
}
private:
- QString fDateFormat;
- QValueVector<int> fCustomMapping;
+ TQString fDateFormat;
+ TQValueVector<int> fCustomMapping;
int fOtherPhone;
bool fPreferHome;
int fFaxTypeOnPC;
@@ -165,12 +165,12 @@ namespace KABCSync
* @return Category index that best matches.
* @return Pilot::Unfiled if no best match.
*/
- unsigned int bestMatchedCategory(const QStringList &categorynames,
+ unsigned int bestMatchedCategory(const TQStringList &categorynames,
const PilotAddressInfo &info,
unsigned int category);
/** As above, but return the name of the category. */
- inline QString bestMatchedCategoryName(const QStringList &categorynames,
+ inline TQString bestMatchedCategoryName(const TQStringList &categorynames,
const PilotAddressInfo &info,
unsigned int category)
{
@@ -181,14 +181,14 @@ namespace KABCSync
/** Give the addressee @p abEntry the category @p cat (leaving
* existing category assignments intact).
*/
- void setCategory(KABC::Addressee &abEntry, const QString &cat);
+ void setCategory(KABC::Addressee &abEntry, const TQString &cat);
/* These are string identifiers used for custom properties in the addressees,
* used to store KPilot-specific settings.
*/
- const QString appString=CSL1("KPILOT"); ///< Identifier for the application
- const QString flagString=CSL1("Flag"); ///< Flags: synced or not
- const QString idString=CSL1("RecordID"); ///< Record ID on HH for this addressee
+ const TQString appString=CSL1("KPILOT"); ///< Identifier for the application
+ const TQString flagString=CSL1("Flag"); ///< Flags: synced or not
+ const TQString idString=CSL1("RecordID"); ///< Record ID on HH for this addressee
/** Get the string value for HH custom field @p index (0..3) from the addressee
@@ -199,9 +199,9 @@ namespace KABCSync
* string @p dateFormat. If this is empty, use the locale setting.
*
* @return String value for HH custom field @p index
* @return Null QString on error (is also a valid return value)
*/
- QString getFieldForHHCustom(
+ TQString getFieldForHHCustom(
unsigned int index,
const KABC::Addressee &abEntry,
const Settings &settings);
@@ -215,7 +215,7 @@ namespace KABCSync
void setFieldFromHHCustom(
const unsigned int index,
KABC::Addressee &abEntry,
- const QString &value,
+ const TQString &value,
const Settings &settings);
/** The HH has a phone type "other" which may be mapped to any one of
@@ -223,7 +223,7 @@ namespace KABCSync
*
* @note @p mappingForOther should come from AbbrowserSettings::pilotOther()
*/
- QString getFieldForHHOtherPhone(const KABC::Addressee &abEntry, const Settings &s);
+ TQString getFieldForHHOtherPhone(const KABC::Addressee &abEntry, const Settings &s);
/** The HH has a phone type "other" which may be mapped to any one
* of several PC side phone numbers. Store the number @p nr in the
@@ -231,7 +231,7 @@ namespace KABCSync
*
* @note @p mappingForOther should come from AbbrowserSettings::pilotOther()
*/
- void setFieldFromHHOtherPhone(KABC::Addressee &abEntry, const QString &nr, const Settings &s);
+ void setFieldFromHHOtherPhone(KABC::Addressee &abEntry, const TQString &nr, const Settings &s);
/** Returns the address portion of an addressee. Since the HH can only store
* one address, we return the preferred address (if the Addressee @p abEntry
@@ -199,9 +199,9 @@ namespace KABCSync
*
* @return String value for HH custom field @p index
- * @return Null QString on error (is also a valid return value)
+ * @return Null TQString on error (is also a valid return value)
*/